@@ -48,6 +48,18 @@ impl<T, const INLINE_LEN: usize> From<Vec<T>> for SmallArrayBox<T, INLINE_LEN> {
     }
 }
 
+impl<T: Clone, const INLINE_LEN: usize> From<&[T]> for SmallArrayBox<T, INLINE_LEN> {
+    fn from(slice: &[T]) -> Self {
+        Self::new(slice.iter().cloned())
+    }
+}
+
+impl<T: Clone, const INLINE_LEN: usize> Clone for SmallArrayBox<T, INLINE_LEN> {
+    fn clone(&self) -> Self {
+        Self::new(self.iter().cloned())
+    }
+}
+
 impl<T, const INLINE_LEN: usize> SmallArrayBox<T, INLINE_LEN> {
     pub(crate) fn uninit_inline_storage() -> Self {
         Self {
@@ -81,7 +93,7 @@ impl<T, const INLINE_LEN: usize> SmallArrayBox<T, INLINE_LEN> {
             let inline_storage = unsafe { this.storage.inline_storage.deref_mut() };
 
             iter.zip(inline_storage).for_each(|(src, dst)| {
-                dst.write(src);
+                *dst = MaybeUninit::new(src);
             });
 
             this.len = len;
